[PATCH 16/17] v4: rename do_command() to do_command4()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Maciej Åenczykowski <maze@xxxxxxxxxx>

Signed-off-by: Maciej Åenczykowski <maze@xxxxxxxxxx>
---
 include/iptables.h    |    2 +-
 iptables-restore.c    |    4 ++--
 iptables-standalone.c |    2 +-
 iptables-xml.c        |    2 +-
 iptables.c            |    6 +++---
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/include/iptables.h b/include/iptables.h
index 204c92e..65b3290 100644
--- a/include/iptables.h
+++ b/include/iptables.h
@@ -7,7 +7,7 @@
 #include <iptables/internal.h>
 
 /* Your shared library should call one of these. */
-extern int do_command(int argc, char *argv[], char **table,
+extern int do_command4(int argc, char *argv[], char **table,
 		      struct iptc_handle **handle);
 extern int delete_chain4(const ipt_chainlabel chain, int verbose,
 			struct iptc_handle *handle);
diff --git a/iptables-restore.c b/iptables-restore.c
index 6163a92..e4f0604 100644
--- a/iptables-restore.c
+++ b/iptables-restore.c
@@ -438,13 +438,13 @@ main(int argc, char *argv[])
 				}
 			}
 
-			DEBUGP("calling do_command(%u, argv, &%s, handle):\n",
+			DEBUGP("calling do_command4(%u, argv, &%s, handle):\n",
 				newargc, curtable);
 
 			for (a = 0; a < newargc; a++)
 				DEBUGP("argv[%u]: %s\n", a, newargv[a]);
 
-			ret = do_command(newargc, newargv,
+			ret = do_command4(newargc, newargv,
 					 &newargv[2], &handle);
 
 			free_argv();
diff --git a/iptables-standalone.c b/iptables-standalone.c
index 38dd2c2..b085946 100644
--- a/iptables-standalone.c
+++ b/iptables-standalone.c
@@ -62,7 +62,7 @@ main(int argc, char *argv[])
 	init_extensions4();
 #endif
 
-	ret = do_command(argc, argv, &table, &handle);
+	ret = do_command4(argc, argv, &table, &handle);
 	if (ret) {
 		ret = iptc_commit(handle);
 		iptc_free(handle);
diff --git a/iptables-xml.c b/iptables-xml.c
index 57c7486..dc3cd4f 100644
--- a/iptables-xml.c
+++ b/iptables-xml.c
@@ -844,7 +844,7 @@ main(int argc, char *argv[])
 				}
 			}
 
-			DEBUGP("calling do_command(%u, argv, &%s, handle):\n",
+			DEBUGP("calling do_command4(%u, argv, &%s, handle):\n",
 			       newargc, curTable);
 
 			for (a = 0; a < newargc; a++)
diff --git a/iptables.c b/iptables.c
index b7c9498..0995d6f 100644
--- a/iptables.c
+++ b/iptables.c
@@ -1413,7 +1413,7 @@ static void command_match(struct iptables_command_state *cs)
 	}
 }
 
-int do_command(int argc, char *argv[], char **table, struct iptc_handle **handle)
+int do_command4(int argc, char *argv[], char **table, struct iptc_handle **handle)
 {
 	struct iptables_command_state cs;
 	struct ipt_entry *e = NULL;
@@ -1437,11 +1437,11 @@ int do_command(int argc, char *argv[], char **table, struct iptc_handle **handle
 	cs.jumpto = "";
 	cs.argv = argv;
 
 	/* re-set optind to 0 in case do_command gets called
 	 * a second time */
 	optind = 0;
 
 	/* clear mflags in case do_command gets called a second time
 	 * (we clear the global list of all matches for security)*/
 	for (m = xtables_matches; m; m = m->next)
 		m->mflags = 0;
@@ -1437,11 +1437,11 @@ int do_command(int argc, char *argv[], char **table, struct iptc_handle **handle
 	cs.argv = argv;
 
-	/* re-set optind to 0 in case do_command gets called
+	/* re-set optind to 0 in case do_command4 gets called
 	 * a second time */
 	optind = 0;
@@ -1437,11 +1437,11 @@ int do_command(int argc, char *argv[], char **table, struct iptc_handle **handle
 	optind = 0;
 
-	/* clear mflags in case do_command gets called a second time
+	/* clear mflags in case do_command4 gets called a second time
 	 * (we clear the global list of all matches for security)*/
 	for (m = xtables_matches; m; m = m->next)
-- 
1.7.3.1

--
To unsubscribe from this list: send the line "unsubscribe netfilter-devel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Netfitler Users]     [LARTC]     [Bugtraq]     [Yosemite Forum]

  Powered by Linux